@@ -25,12 +25,17 @@ package com.openexchange.documentconverter;
 public enum BackendType {
 
     /**
-     * Apache Open Office
+     * AOO or LIBO
      */
-    APOO,
+    READERENGINE,
 
     /**
-     * Libre Office
+     * PDFTool
      */
-    LIBO
+    PDFTOOL,
+
+    /**
+     * SharePoint
+     */
+    SHAREPOINT
 }
