@@ -98,6 +98,11 @@ public class Config {
      * Force usage of SharepointServer despite setting of job property (capability) on e.g. remote conversion server
      */
     public boolean ENGINE_FORCE_SHAREPOINT_CONVERSION = false;
+    
+    /**
+     * the number of engines, working in parallel to execute SharePoint jobs;
+     */
+    public int ENGINE_JOB_SHAREPOINT_PROCESSOR_COUNT = 3;
 
     /**
      * the location of the log
