@@ -88,5 +88,5 @@ public interface ICache {
     /**
     * Tells the cache to perform internal management tasks, e.g. update statistics, cleanup etc.
     */
-    public void update();
+    public void update(boolean logInfoAtNextTimeslot);
 }
