@@ -62,12 +62,12 @@ public interface ICacheEntry extends Serializable {
     /**
      * Locks the entry, so that it won't be removed from the cache.
      */
-    public void acquireLock();
+    public void acquireLock(boolean synchronize);
 
     /**
      * Releases the entry lock, so that it can be removed from the cache.
      */
-    public void releaseLock();
+    public void releaseLock(boolean synchronize);
 
     /**
      * @return True if this object is currently locked
