@@ -68,6 +68,11 @@ public interface IDocumentConverterInformationMBean {
 
     // -------------------------------------------------------------------------
 
+    /**
+     * @return The peak number of Jobs in queue for the given priority from the beginning of the last reset/initialization on
+     */
+    int getPeakJobCountInQueue_Background();
+
     /**
      * @return The peak number of Jobs in queue for the given priority from the beginning of the last reset/initialization on
      */
@@ -108,6 +113,11 @@ public interface IDocumentConverterInformationMBean {
 
     // -------------------------------------------------------------------------
 
+    /**
+     * @return The median of the jobs time in queue for the given priority from the beginning of the last reset/initialization on
+     */
+    long getMedianQueueTimeMillis_Background();
+
     /**
      * @return The median of the jobs time in queue for the given priority from the beginning of the last reset/initialization on
      */
@@ -135,6 +145,11 @@ public interface IDocumentConverterInformationMBean {
 
     // -------------------------------------------------------------------------
 
+    /**
+     * @return The median of the jobs conversion time for the given priority from the beginning of the last reset/initialization on
+     */
+    long getMedianConversionTimeMillis_Background();
+
     /**
      * @return The median of the jobs conversion time for the given priority from the beginning of the last reset/initialization on
      */
@@ -162,6 +177,11 @@ public interface IDocumentConverterInformationMBean {
 
     // -------------------------------------------------------------------------
 
+    /**
+     * @return The median of the jobs total time for the given priority from the beginning of the last reset/initialization on
+     */
+    long getMedianJobTimeMillis_Background();
+
     /**
      * @return The median of the jobs total time for the given priority from the beginning of the last reset/initialization on
      */
