@@ -57,7 +57,7 @@ public interface IJob {
      * @return <code>true</code>, if the implemented execute method needs an
      *  {@link IInstance} interface to work with, <code>false</code> otherwise
      */
-    abstract boolean needsReaderengine();
+    abstract BackendType backendTypeNeeded();
 
     /**
      * This method will be called in order to let the job do the real work
