@@ -30,7 +30,7 @@ public interface IJobProcessor {
      * @param backendDescriptors
      * @return
      */
-    boolean init(BackendDescriptor[] backendDescriptors);
+    boolean init(ReaderengineDescriptor[] readerengineDescriptors);
 
     /**
      * Adds a new Job to the processor
