@@ -33,7 +33,7 @@ public interface IManager {
      * @param cacheDescriptor contains properties to setup a cache
      * @return the JobProcessor to execute single jobs or null in case of failure
      */
-    public IJobProcessor init(BackendDescriptor backendDescriptors[], CacheDescriptor cacheDescriptor);
+    public IJobProcessor init(ReaderengineDescriptor readerengineDescriptors[], CacheDescriptor cacheDescriptor);
 
     /**
      * kills all engine instances etc. and leaves the service with a clean status
