@@ -20,16 +20,35 @@ package com.openexchange.documentconverter;
  */
 public class LogData {
 
-    String key;
-    String value;
-
-    public LogData( final String _key, final String _value ) {
-        key = _key;
-        value = _value;
+    /**
+     * Initializes a new {@link LogData}.
+     * 
+     * @param _key
+     * @param _value
+     */
+    public LogData(final String _key, final String _value) {
+        m_key = _key;
+        m_value = _value;
     }
 
-    public String getKey() { return key; }
+    /**
+     * @return
+     */
+    public String getKey() {
+        return ((null != m_key) ? m_key : "null");
+    }
 
-    public String getValue() { return value; }
+    /**
+     * @return
+     */
+    public String getValue() {
+        return ((null != m_value) ? m_value : "null");
+    }
+
+    // - Members ---------------------------------------------------------------
+
+    private String m_key;
+
+    private String m_value;
 
 }
