@@ -85,6 +85,8 @@ public class Properties {
 
     static final public String PROP_PIXEL_HEIGHT = "PixelHeight"; // Integer
 
+    static final public String PROP_PIXEL_ZOOM= "PixelZoom"; // Double
+
     static final public String PROP_INPUT_FILE = "InputFile"; // File
 
     static final public String PROP_INPUT_STREAM = "InputStream"; // InputStream
@@ -122,9 +124,15 @@ public class Properties {
     static final public String PROP_CONVERTER_COOKIE = "ConverterCookie"; // String
 
     static final public String PROP_CACHE_ONLY = "CacheOnly"; // Boolean
-
+    
     static final public String PROP_AUTOSCALE = "AutoScale"; // Boolean
 
+    static final public String PROP_HIDE_CHANGES = "HideChanges"; // Boolean
+
+    static final public String PROP_HIDE_COMMENTS = "HideComments"; // Boolean
+
+    static final public String PROP_ASYNC = "Async"; // Boolean
+
     // -------------------------------------------------------------------------
 
     static final public String PROP_RESULT_CACHE_HASH = PROP_CACHE_HASH; // String
